# definition-generator
Tool to create stylish definitions from structured input

# Example output
![out12](https://user-images.githubusercontent.com/41017214/109725016-313a4280-7bb9-11eb-91fb-8389f41eae44.jpg)
![out13](https://user-images.githubusercontent.com/41017214/109725093-4a42f380-7bb9-11eb-80c2-7a572e35ac53.jpg)

# Some pypi commands

pip install setuptools twine
python3 setup.py sdist
twine upload --repository-url https://upload.pypi.org/legacy/ --skip-existing dist/*